@@ -54,7 +54,7 @@ single.simulation.loop <- function(i, object, save.data, load.data, data.path =
     obs.table <- dist.data$obs.table
     sample.table <- dist.data$sample.table
     region.table <- dist.data$region.table
-    n.in.covered <- dist.data$n.in.covered 
+    dists.in.covered <- dist.data$n.in.covered 
   }else{
     #simulate survey
     survey.data <- create.survey.results(object = survey, dht.tables = TRUE, region = object@region)
@@ -62,22 +62,23 @@ single.simulation.loop <- function(i, object, save.data, load.data, data.path =
     obs.table <- survey.data$obs.table
     sample.table <- survey.data$sample.table
     region.table <- survey.data$region.table
-    n.in.covered <- survey.data$n.in.covered 
+    dists.in.covered <- survey.data$n.in.covered 
     if(save.data){
-      dist.data <- list(ddf = ddf.data, obs.table = obs.table, sample.table = sample.table, region.table = region.table, n.in.covered = n.in.covered)  
+      dist.data <- list(ddf = ddf.data, obs.table = obs.table, sample.table = sample.table, region.table = region.table, n.in.covered = dists.in.covered)  
       save(dist.data, file = paste(data.path,"dataset_",i,".robj", sep = ""))
     }
   }
   #Find how many animals were in the covered region
   if(length(object@ddf.analyses[[1]]@truncation) > 0){
-    n.in.covered <- length(which(n.in.covered <= object@ddf.analyses[[1]]@truncation))  
+    n.in.covered <- length(which(dists.in.covered <= object@ddf.analyses[[1]]@truncation))  
   }else{
-    n.in.covered <- length(n.in.covered)
+    n.in.covered <- length(dists.in.covered)
   }
   #analyse survey if there are data to analyse
   if(nrow(ddf.data@ddf.dat[!is.na(ddf.data@ddf.dat$distance),]) >= 20){
     ddf.results <- run.analysis(object, ddf.data)
     warnings <- ddf.results$warnings
+    num.successful.models <- ddf.results$num.successful.models
     ddf.results <- ddf.results$best.model
   }else{
     warning("There are too few data points (<20) to be analysed, skipping this iteration.", call. = FALSE, immediate. = TRUE)
@@ -86,7 +87,7 @@ single.simulation.loop <- function(i, object, save.data, load.data, data.path =
   #Check at least one model worked
   if(!is.null(ddf.results)){
     #Store ddf results
-    object@results$Detection <- store.ddf.results(object@results$Detection, ddf.results, i, n.in.covered)
+    object@results$Detection <- store.ddf.results(object@results$Detection, ddf.results, i, n.in.covered, num.successful.models)
     #Check to see if the stratification is to be modified for analysis
     analysis.strata <- object@ddf.analyses[[1]]@analysis.strata
     if(nrow(analysis.strata) > 0){
